==> qtjambi-dbus-debuginfo-macos-5.15.20.jar: sources/QtJambiDBus/QDBusObjectPath_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtDBus/qdbusextratypes.h>
#include <QtCore/QVariant>
#include <QtCore/qstring.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDBusObjectPath(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDBusObjectPath")
    QDBusObjectPath *_ptr = reinterpret_cast<QDBusObjectPath *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDBusObjectPath()
void __qt_construct_QDBusObjectPath(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusObjectPath()")
    Q_UNUSED(__java_arguments)
    QDBusObjectPath *__qt_this = new(__qtjambi_ptr) QDBusObjectPath();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QDBusObjectPath::QDBusObjectPath()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_initialize_1native__Lio_qt_dbus_QDBusObjectPath_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusObjectPath::QDBusObjectPath()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusObjectPath, sizeof(QDBusObjectPath), typeid(QDBusObjectPath), false, &deleter_QDBusObjectPath, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDBusObjectPath(QDBusObjectPath)
void __qt_construct_QDBusObjectPath_cref_QDBusObjectPath(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusObjectPath(QDBusObjectPath)")
    jobject other0 = __java_arguments[0].l;
    const QDBusObjectPath& __qt_other0 = qtjambi_cast<const QDBusObjectPath& >(__jni_env, other0);
    QDBusObjectPath *__qt_this = new(__qtjambi_ptr) QDBusObjectPath(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDBusObjectPath::QDBusObjectPath(QDBusObjectPath)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_initialize_1native__Lio_qt_dbus_QDBusObjectPath_2Lio_qt_dbus_QDBusObjectPath_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusObjectPath::QDBusObjectPath(QDBusObjectPath)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusObjectPath_cref_QDBusObjectPath, sizeof(QDBusObjectPath), typeid(QDBusObjectPath), false, &deleter_QDBusObjectPath, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDBusObjectPath(QString&&)
void __qt_construct_QDBusObjectPath_rval_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusObjectPath(QString&&)")
    jobject p0 = __java_arguments[0].l;
    QString& __qt_p0 = qtjambi_cast<QString& >(__jni_env, p0);
    QDBusObjectPath *__qt_this = new(__qtjambi_ptr) QDBusObjectPath(std::move(__qt_p0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDBusObjectPath::QDBusObjectPath(QString&&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_initialize_1native__Lio_qt_dbus_QDBusObjectPath_2Ljava_lang_CharSequence_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject p0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusObjectPath::QDBusObjectPath(QString&&)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = p0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusObjectPath_rval_QString, sizeof(QDBusObjectPath), typeid(QDBusObjectPath), false, &deleter_QDBusObjectPath, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDBusObjectPath(QString)
void __qt_construct_QDBusObjectPath_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusObjectPath(QString)")
    jstring path0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_path0 = qtjambi_cast<QString>(__jni_env, path0);
    QDBusObjectPath *__qt_this = new(__qtjambi_ptr) QDBusObjectPath(__qt_path0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDBusObjectPath::QDBusObjectPath(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_initialize_1native__Lio_qt_dbus_QDBusObjectPath_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring path0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusObjectPath::QDBusObjectPath(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = path0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusObjectPath_cref_QString, sizeof(QDBusObjectPath), typeid(QDBusObjectPath), false, &deleter_QDBusObjectPath, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDBusObjectPath
void __qt_destruct_QDBusObjectPath(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDBusObjectPath")
    reinterpret_cast<QDBusObjectPath*>(ptr)->~QDBusObjectPath();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDBusObjectPath::operator<(QDBusObjectPath,QDBusObjectPath)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_operator_1less_1native_1cref_1QDBusObjectPath__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusObjectPath::operator<(QDBusObjectPath,QDBusObjectPath)", __qt_this)
        const QDBusObjectPath& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QDBusObjectPath>(rhs1);
        __java_return_value = (*__qt_this) < __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusObjectPath::operator==(QDBusObjectPath,QDBusObjectPath)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_equals_1native_1cref_1QDBusObjectPath__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusObjectPath::operator==(QDBusObjectPath,QDBusObjectPath)", __qt_this)
        const QDBusObjectPath& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QDBusObjectPath>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusObjectPath::path()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_path_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusObjectPath::path()const", __qt_this)
        QString __qt_return_value = __qt_this->path();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusObjectPath::setPath(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_setPath_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring path0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusObjectPath::setPath(QString)", __qt_this)
        QString  __qt_path0 = qtjambi_cast<QString>(__jni_env, path0);
        __qt_this->setPath(__qt_path0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusObjectPath::swap(QDBusObjectPath&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_swap_1native_1ref_1QDBusObjectPath__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusObjectPath::swap(QDBusObjectPath&)", __qt_this)
        QDBusObjectPath& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDBusObjectPath>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDBusObjectPath(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDBusObjectPath>("QDBusObjectPath", "io/qt/dbus/QDBusObjectPath");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDBusObjectPath, {
        ConstructorInfo(&__qt_construct_QDBusObjectPath, nullptr)
       ,ConstructorInfo(&__qt_construct_QDBusObjectPath_cref_QDBusObjectPath, "Lio/qt/dbus/QDBusObjectPath;")
       ,ConstructorInfo(&__qt_construct_QDBusObjectPath_rval_QString, "Lio/qt/core/QString;")
       ,ConstructorInfo(&__qt_construct_QDBusObjectPath_cref_QString, "Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDBusObjectPath);
    registerMetaType<QDBusObjectPath>("QDBusObjectPath");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-dbus-debuginfo-macos-6.5.3.jar: sources/QtJambiDBus/QDBusObjectPath_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtDBus/qdbusextratypes.h>
#include <QtCore/QVariant>
#include <QtCore/qstring.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDBusObjectPath(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDBusObjectPath")
    QDBusObjectPath *_ptr = reinterpret_cast<QDBusObjectPath *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDBusObjectPath()
void __qt_construct_QDBusObjectPath_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusObjectPath()")
    Q_UNUSED(__java_arguments)
    QDBusObjectPath *__qt_this = new(__qtjambi_ptr) QDBusObjectPath();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QDBusObjectPath(QString&&)
void __qt_construct_QDBusObjectPath_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusObjectPath(QString&&)")
    jobject p0 = __java_arguments[0].l;
    QString& __qt_p0 = qtjambi_cast<QString& >(__jni_env, p0);
    QDBusObjectPath *__qt_this = new(__qtjambi_ptr) QDBusObjectPath(std::move(__qt_p0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QDBusObjectPath(QString)
void __qt_construct_QDBusObjectPath_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusObjectPath(QString)")
    jstring path0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_path0 = qtjambi_cast<QString >(__jni_env, path0);
    QDBusObjectPath *__qt_this = new(__qtjambi_ptr) QDBusObjectPath(__qt_path0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QDBusObjectPath
void __qt_destruct_QDBusObjectPath(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDBusObjectPath")
    reinterpret_cast<QDBusObjectPath*>(ptr)->~QDBusObjectPath();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDBusObjectPath::QDBusObjectPath()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_initialize_1native__Lio_qt_dbus_QDBusObjectPath_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusObjectPath::QDBusObjectPath()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusObjectPath_0, sizeof(QDBusObjectPath), typeid(QDBusObjectPath), false, &deleter_QDBusObjectPath, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusObjectPath::QDBusObjectPath(QString&&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_initialize_1native__Lio_qt_dbus_QDBusObjectPath_2Ljava_lang_CharSequence_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject p0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusObjectPath::QDBusObjectPath(QString&&)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = p0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusObjectPath_1, sizeof(QDBusObjectPath), typeid(QDBusObjectPath), false, &deleter_QDBusObjectPath, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusObjectPath::QDBusObjectPath(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_initialize_1native__Lio_qt_dbus_QDBusObjectPath_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring path0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusObjectPath::QDBusObjectPath(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = path0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusObjectPath_2, sizeof(QDBusObjectPath), typeid(QDBusObjectPath), false, &deleter_QDBusObjectPath, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusObjectPath::operator<(QDBusObjectPath,QDBusObjectPath)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_operator_1less_1native_1cref_1QDBusObjectPath__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusObjectPath::operator<(QDBusObjectPath,QDBusObjectPath)", __qt_this)
        const QDBusObjectPath& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QDBusObjectPath>(rhs1);
        __java_return_value = (*__qt_this) < __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusObjectPath::operator==(QDBusObjectPath,QDBusObjectPath)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_operator_1equal_1native_1cref_1QDBusObjectPath__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusObjectPath::operator==(QDBusObjectPath,QDBusObjectPath)", __qt_this)
        const QDBusObjectPath& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QDBusObjectPath>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusObjectPath::path()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_path_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusObjectPath::path()const", __qt_this)
        QString __qt_return_value = __qt_this->path();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusObjectPath::setPath(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_setPath_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring path0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusObjectPath::setPath(QString)", __qt_this)
        QString  __qt_path0 = qtjambi_cast<QString >(__jni_env, path0);
        __qt_this->setPath(__qt_path0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusObjectPath::swap(QDBusObjectPath&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_swap_1native_1ref_1QDBusObjectPath__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusObjectPath::swap(QDBusObjectPath&)", __qt_this)
        QDBusObjectPath& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDBusObjectPath>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusObjectPath_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDBusObjectPath *__qt_this = QtJambiAPI::objectFromNativeId<QDBusObjectPath>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDBusObjectPath(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDBusObjectPath>("QDBusObjectPath", "io/qt/dbus/QDBusObjectPath");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDBusObjectPath, {
        ConstructorInfo(&__qt_construct_QDBusObjectPath_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QDBusObjectPath_1, "Lio/qt/core/QString;")
       ,ConstructorInfo(&__qt_construct_QDBusObjectPath_2, "Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDBusObjectPath);
    registerMetaType<QDBusObjectPath>("QDBusObjectPath");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
